.. services.archiver.external_tar_archiver_provider.rst
..
.. Project: AutoArchive
.. License: GNU GPLv3
..
.. Copyright (C) 2003 - 2026 Róbert Čerňanský



.. A section for the AutoArchive._services.archiver._external_tar_archiver_provider package.



AutoArchive._services.archiver._external_tar_archiver_provider
==============================================================

.. automodule:: AutoArchive._services.archiver._external_tar_archiver_provider
   :no-members:



Modules
-------

external_tar_archiver_provider
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._services.archiver._external_tar_archiver_provider.external_tar_archiver_provider


_external_tar_incremental_utility
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._services.archiver._external_tar_archiver_provider._external_tar_incremental_utility
.. autoclass:: _ExternalTarIncrementalUtility
